==> huaweicloudsdkcce-3.0.33rc0-py3-none-any.whl: huaweicloudsdkcce/v3/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import CceClient
from huaweicloudsdkcce.v3.cce_client import CceClient
from huaweicloudsdkcce.v3.cce_async_client import CceAsyncClient
# import models into sdk package
from huaweicloudsdkcce.v3.model.addon_instance import AddonInstance
from huaweicloudsdkcce.v3.model.addon_instance_status import AddonInstanceStatus
from huaweicloudsdkcce.v3.model.addon_template import AddonTemplate
from huaweicloudsdkcce.v3.model.authenticating_proxy import AuthenticatingProxy
from huaweicloudsdkcce.v3.model.authentication import Authentication
from huaweicloudsdkcce.v3.model.awake_cluster_request import AwakeClusterRequest
from huaweicloudsdkcce.v3.model.awake_cluster_response import AwakeClusterResponse
from huaweicloudsdkcce.v3.model.cce_cluster_node_information import CCEClusterNodeInformation
from huaweicloudsdkcce.v3.model.cce_cluster_node_information_metadata import CCEClusterNodeInformationMetadata
from huaweicloudsdkcce.v3.model.cce_job import CCEJob
from huaweicloudsdkcce.v3.model.cce_job_metadata import CCEJobMetadata
from huaweicloudsdkcce.v3.model.cce_job_spec import CCEJobSpec
from huaweicloudsdkcce.v3.model.cce_job_status import CCEJobStatus
from huaweicloudsdkcce.v3.model.cert_duration import CertDuration
from huaweicloudsdkcce.v3.model.cluster_cert import ClusterCert
from huaweicloudsdkcce.v3.model.cluster_endpoints import ClusterEndpoints
from huaweicloudsdkcce.v3.model.cluster_information import ClusterInformation
from huaweicloudsdkcce.v3.model.cluster_information_spec import ClusterInformationSpec
from huaweicloudsdkcce.v3.model.cluster_metadata import ClusterMetadata
from huaweicloudsdkcce.v3.model.cluster_status import ClusterStatus
from huaweicloudsdkcce.v3.model.clusters import Clusters
from huaweicloudsdkcce.v3.model.container_network import ContainerNetwork
from huaweicloudsdkcce.v3.model.context import Context
from huaweicloudsdkcce.v3.model.contexts import Contexts
from huaweicloudsdkcce.v3.model.create_addon_instance_request import CreateAddonInstanceRequest
from huaweicloudsdkcce.v3.model.create_addon_instance_response import CreateAddonInstanceResponse
from huaweicloudsdkcce.v3.model.create_cloud_persistent_volume_claims_request import CreateCloudPersistentVolumeClaimsRequest
from huaweicloudsdkcce.v3.model.create_cloud_persistent_volume_claims_response import CreateCloudPersistentVolumeClaimsResponse
from huaweicloudsdkcce.v3.model.create_cluster_request import CreateClusterRequest
from huaweicloudsdkcce.v3.model.create_cluster_response import CreateClusterResponse
from huaweicloudsdkcce.v3.model.create_kubernetes_cluster_cert_request import CreateKubernetesClusterCertRequest
from huaweicloudsdkcce.v3.model.create_kubernetes_cluster_cert_response import CreateKubernetesClusterCertResponse
from huaweicloudsdkcce.v3.model.create_node_pool_request import CreateNodePoolRequest
from huaweicloudsdkcce.v3.model.create_node_pool_response import CreateNodePoolResponse
from huaweicloudsdkcce.v3.model.create_node_request import CreateNodeRequest
from huaweicloudsdkcce.v3.model.create_node_response import CreateNodeResponse
from huaweicloudsdkcce.v3.model.data_volume_metadata import DataVolumeMetadata
from huaweicloudsdkcce.v3.model.delete_addon_instance_request import DeleteAddonInstanceRequest
from huaweicloudsdkcce.v3.model.delete_addon_instance_response import DeleteAddonInstanceResponse
from huaweicloudsdkcce.v3.model.delete_cloud_persistent_volume_claims_request import DeleteCloudPersistentVolumeClaimsRequest
from huaweicloudsdkcce.v3.model.delete_cloud_persistent_volume_claims_response import DeleteCloudPersistentVolumeClaimsResponse
from huaweicloudsdkcce.v3.model.delete_cluster_request import DeleteClusterRequest
from huaweicloudsdkcce.v3.model.delete_cluster_response import DeleteClusterResponse
from huaweicloudsdkcce.v3.model.delete_node_pool_request import DeleteNodePoolRequest
from huaweicloudsdkcce.v3.model.delete_node_pool_response import DeleteNodePoolResponse
from huaweicloudsdkcce.v3.model.delete_node_request import DeleteNodeRequest
from huaweicloudsdkcce.v3.model.delete_node_response import DeleteNodeResponse
from huaweicloudsdkcce.v3.model.delete_status import DeleteStatus
from huaweicloudsdkcce.v3.model.eni_network import ENINetwork
from huaweicloudsdkcce.v3.model.hibernate_cluster_request import HibernateClusterRequest
from huaweicloudsdkcce.v3.model.hibernate_cluster_response import HibernateClusterResponse
from huaweicloudsdkcce.v3.model.host_network import HostNetwork
from huaweicloudsdkcce.v3.model.instance_request import InstanceRequest
from huaweicloudsdkcce.v3.model.instance_request_spec import InstanceRequestSpec
from huaweicloudsdkcce.v3.model.instance_spec import InstanceSpec
from huaweicloudsdkcce.v3.model.list_addon_instances_request import ListAddonInstancesRequest
from huaweicloudsdkcce.v3.model.list_addon_instances_response import ListAddonInstancesResponse
from huaweicloudsdkcce.v3.model.list_addon_templates_request import ListAddonTemplatesRequest
from huaweicloudsdkcce.v3.model.list_addon_templates_response import ListAddonTemplatesResponse
from huaweicloudsdkcce.v3.model.list_clusters_request import ListClustersRequest
from huaweicloudsdkcce.v3.model.list_clusters_response import ListClustersResponse
from huaweicloudsdkcce.v3.model.list_node_pools_request import ListNodePoolsRequest
from huaweicloudsdkcce.v3.model.list_node_pools_response import ListNodePoolsResponse
from huaweicloudsdkcce.v3.model.list_nodes_request import ListNodesRequest
from huaweicloudsdkcce.v3.model.list_nodes_response import ListNodesResponse
from huaweicloudsdkcce.v3.model.login import Login
from huaweicloudsdkcce.v3.model.master_spec import MasterSpec
from huaweicloudsdkcce.v3.model.metadata import Metadata
from huaweicloudsdkcce.v3.model.nic_spec import NicSpec
from huaweicloudsdkcce.v3.model.node_management import NodeManagement
from huaweicloudsdkcce.v3.model.node_metadata import NodeMetadata
from huaweicloudsdkcce.v3.model.node_nic_spec import NodeNicSpec
from huaweicloudsdkcce.v3.model.node_pool import NodePool
from huaweicloudsdkcce.v3.model.node_pool_metadata import NodePoolMetadata
from huaweicloudsdkcce.v3.model.node_pool_node_autoscaling import NodePoolNodeAutoscaling
from huaweicloudsdkcce.v3.model.node_pool_spec import NodePoolSpec
from huaweicloudsdkcce.v3.model.node_pool_status import NodePoolStatus
from huaweicloudsdkcce.v3.model.persistent_volume_claim import PersistentVolumeClaim
from huaweicloudsdkcce.v3.model.persistent_volume_claim_metadata import PersistentVolumeClaimMetadata
from huaweicloudsdkcce.v3.model.persistent_volume_claim_spec import PersistentVolumeClaimSpec
from huaweicloudsdkcce.v3.model.persistent_volume_claim_status import PersistentVolumeClaimStatus
from huaweicloudsdkcce.v3.model.resource_requirements import ResourceRequirements
from huaweicloudsdkcce.v3.model.resource_tag import ResourceTag
from huaweicloudsdkcce.v3.model.show_addon_instance_request import ShowAddonInstanceRequest
from huaweicloudsdkcce.v3.model.show_addon_instance_response import ShowAddonInstanceResponse
from huaweicloudsdkcce.v3.model.show_cluster_metadata import ShowClusterMetadata
from huaweicloudsdkcce.v3.model.show_cluster_request import ShowClusterRequest
from huaweicloudsdkcce.v3.model.show_cluster_response import ShowClusterResponse
from huaweicloudsdkcce.v3.model.show_job_request import ShowJobRequest
from huaweicloudsdkcce.v3.model.show_job_response import ShowJobResponse
from huaweicloudsdkcce.v3.model.show_node_pool_request import ShowNodePoolRequest
from huaweicloudsdkcce.v3.model.show_node_pool_response import ShowNodePoolResponse
from huaweicloudsdkcce.v3.model.show_node_request import ShowNodeRequest
from huaweicloudsdkcce.v3.model.show_node_response import ShowNodeResponse
from huaweicloudsdkcce.v3.model.support_versions import SupportVersions
from huaweicloudsdkcce.v3.model.taint import Taint
from huaweicloudsdkcce.v3.model.templatespec import Templatespec
from huaweicloudsdkcce.v3.model.update_addon_instance_request import UpdateAddonInstanceRequest
from huaweicloudsdkcce.v3.model.update_addon_instance_response import UpdateAddonInstanceResponse
from huaweicloudsdkcce.v3.model.update_cluster_request import UpdateClusterRequest
from huaweicloudsdkcce.v3.model.update_cluster_response import UpdateClusterResponse
from huaweicloudsdkcce.v3.model.update_node_pool_request import UpdateNodePoolRequest
from huaweicloudsdkcce.v3.model.update_node_pool_response import UpdateNodePoolResponse
from huaweicloudsdkcce.v3.model.update_node_request import UpdateNodeRequest
from huaweicloudsdkcce.v3.model.update_node_response import UpdateNodeResponse
from huaweicloudsdkcce.v3.model.user import User
from huaweicloudsdkcce.v3.model.user_password import UserPassword
from huaweicloudsdkcce.v3.model.user_tag import UserTag
from huaweicloudsdkcce.v3.model.users import Users
from huaweicloudsdkcce.v3.model.v3_cluster import V3Cluster
from huaweicloudsdkcce.v3.model.v3_cluster_spec import V3ClusterSpec
from huaweicloudsdkcce.v3.model.v3_data_volume import V3DataVolume
from huaweicloudsdkcce.v3.model.v3_node import V3Node
from huaweicloudsdkcce.v3.model.v3_node_bandwidth import V3NodeBandwidth
from huaweicloudsdkcce.v3.model.v3_node_create_request import V3NodeCreateRequest
from huaweicloudsdkcce.v3.model.v3_node_eip_spec import V3NodeEIPSpec
from huaweicloudsdkcce.v3.model.v3_node_public_ip import V3NodePublicIP
from huaweicloudsdkcce.v3.model.v3_node_spec import V3NodeSpec
from huaweicloudsdkcce.v3.model.v3_node_status import V3NodeStatus
from huaweicloudsdkcce.v3.model.v3_root_volume import V3RootVolume
from huaweicloudsdkcce.v3.model.versions import Versions

==> huaweicloudsdkcce-3.0.40rc0-py3-none-any.whl: huaweicloudsdkcce/v3/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import CceClient
from huaweicloudsdkcce.v3.cce_client import CceClient
from huaweicloudsdkcce.v3.cce_async_client import CceAsyncClient
# import models into sdk package
from huaweicloudsdkcce.v3.model.addon_instance import AddonInstance
from huaweicloudsdkcce.v3.model.addon_instance_status import AddonInstanceStatus
from huaweicloudsdkcce.v3.model.addon_template import AddonTemplate
from huaweicloudsdkcce.v3.model.authenticating_proxy import AuthenticatingProxy
from huaweicloudsdkcce.v3.model.authentication import Authentication
from huaweicloudsdkcce.v3.model.awake_cluster_request import AwakeClusterRequest
from huaweicloudsdkcce.v3.model.awake_cluster_response import AwakeClusterResponse
from huaweicloudsdkcce.v3.model.cce_cluster_node_information import CCEClusterNodeInformation
from huaweicloudsdkcce.v3.model.cce_cluster_node_information_metadata import CCEClusterNodeInformationMetadata
from huaweicloudsdkcce.v3.model.cce_job import CCEJob
from huaweicloudsdkcce.v3.model.cce_job_metadata import CCEJobMetadata
from huaweicloudsdkcce.v3.model.cce_job_spec import CCEJobSpec
from huaweicloudsdkcce.v3.model.cce_job_status import CCEJobStatus
from huaweicloudsdkcce.v3.model.cert_duration import CertDuration
from huaweicloudsdkcce.v3.model.cluster_cert import ClusterCert
from huaweicloudsdkcce.v3.model.cluster_endpoints import ClusterEndpoints
from huaweicloudsdkcce.v3.model.cluster_information import ClusterInformation
from huaweicloudsdkcce.v3.model.cluster_information_spec import ClusterInformationSpec
from huaweicloudsdkcce.v3.model.cluster_metadata import ClusterMetadata
from huaweicloudsdkcce.v3.model.cluster_status import ClusterStatus
from huaweicloudsdkcce.v3.model.clusters import Clusters
from huaweicloudsdkcce.v3.model.container_network import ContainerNetwork
from huaweicloudsdkcce.v3.model.context import Context
from huaweicloudsdkcce.v3.model.contexts import Contexts
from huaweicloudsdkcce.v3.model.create_addon_instance_request import CreateAddonInstanceRequest
from huaweicloudsdkcce.v3.model.create_addon_instance_response import CreateAddonInstanceResponse
from huaweicloudsdkcce.v3.model.create_cloud_persistent_volume_claims_request import CreateCloudPersistentVolumeClaimsRequest
from huaweicloudsdkcce.v3.model.create_cloud_persistent_volume_claims_response import CreateCloudPersistentVolumeClaimsResponse
from huaweicloudsdkcce.v3.model.create_cluster_request import CreateClusterRequest
from huaweicloudsdkcce.v3.model.create_cluster_response import CreateClusterResponse
from huaweicloudsdkcce.v3.model.create_kubernetes_cluster_cert_request import CreateKubernetesClusterCertRequest
from huaweicloudsdkcce.v3.model.create_kubernetes_cluster_cert_response import CreateKubernetesClusterCertResponse
from huaweicloudsdkcce.v3.model.create_node_pool_request import CreateNodePoolRequest
from huaweicloudsdkcce.v3.model.create_node_pool_response import CreateNodePoolResponse
from huaweicloudsdkcce.v3.model.create_node_request import CreateNodeRequest
from huaweicloudsdkcce.v3.model.create_node_response import CreateNodeResponse
from huaweicloudsdkcce.v3.model.data_volume_metadata import DataVolumeMetadata
from huaweicloudsdkcce.v3.model.delete_addon_instance_request import DeleteAddonInstanceRequest
from huaweicloudsdkcce.v3.model.delete_addon_instance_response import DeleteAddonInstanceResponse
from huaweicloudsdkcce.v3.model.delete_cloud_persistent_volume_claims_request import DeleteCloudPersistentVolumeClaimsRequest
from huaweicloudsdkcce.v3.model.delete_cloud_persistent_volume_claims_response import DeleteCloudPersistentVolumeClaimsResponse
from huaweicloudsdkcce.v3.model.delete_cluster_request import DeleteClusterRequest
from huaweicloudsdkcce.v3.model.delete_cluster_response import DeleteClusterResponse
from huaweicloudsdkcce.v3.model.delete_node_pool_request import DeleteNodePoolRequest
from huaweicloudsdkcce.v3.model.delete_node_pool_response import DeleteNodePoolResponse
from huaweicloudsdkcce.v3.model.delete_node_request import DeleteNodeRequest
from huaweicloudsdkcce.v3.model.delete_node_response import DeleteNodeResponse
from huaweicloudsdkcce.v3.model.delete_status import DeleteStatus
from huaweicloudsdkcce.v3.model.eni_network import EniNetwork
from huaweicloudsdkcce.v3.model.hibernate_cluster_request import HibernateClusterRequest
from huaweicloudsdkcce.v3.model.hibernate_cluster_response import HibernateClusterResponse
from huaweicloudsdkcce.v3.model.host_network import HostNetwork
from huaweicloudsdkcce.v3.model.instance_request import InstanceRequest
from huaweicloudsdkcce.v3.model.instance_request_spec import InstanceRequestSpec
from huaweicloudsdkcce.v3.model.instance_spec import InstanceSpec
from huaweicloudsdkcce.v3.model.list_addon_instances_request import ListAddonInstancesRequest
from huaweicloudsdkcce.v3.model.list_addon_instances_response import ListAddonInstancesResponse
from huaweicloudsdkcce.v3.model.list_addon_templates_request import ListAddonTemplatesRequest
from huaweicloudsdkcce.v3.model.list_addon_templates_response import ListAddonTemplatesResponse
from huaweicloudsdkcce.v3.model.list_clusters_request import ListClustersRequest
from huaweicloudsdkcce.v3.model.list_clusters_response import ListClustersResponse
from huaweicloudsdkcce.v3.model.list_node_pools_request import ListNodePoolsRequest
from huaweicloudsdkcce.v3.model.list_node_pools_response import ListNodePoolsResponse
from huaweicloudsdkcce.v3.model.list_nodes_request import ListNodesRequest
from huaweicloudsdkcce.v3.model.list_nodes_response import ListNodesResponse
from huaweicloudsdkcce.v3.model.login import Login
from huaweicloudsdkcce.v3.model.master_spec import MasterSpec
from huaweicloudsdkcce.v3.model.metadata import Metadata
from huaweicloudsdkcce.v3.model.nic_spec import NicSpec
from huaweicloudsdkcce.v3.model.node_management import NodeManagement
from huaweicloudsdkcce.v3.model.node_metadata import NodeMetadata
from huaweicloudsdkcce.v3.model.node_nic_spec import NodeNicSpec
from huaweicloudsdkcce.v3.model.node_pool import NodePool
from huaweicloudsdkcce.v3.model.node_pool_metadata import NodePoolMetadata
from huaweicloudsdkcce.v3.model.node_pool_node_autoscaling import NodePoolNodeAutoscaling
from huaweicloudsdkcce.v3.model.node_pool_spec import NodePoolSpec
from huaweicloudsdkcce.v3.model.node_pool_status import NodePoolStatus
from huaweicloudsdkcce.v3.model.persistent_volume_claim import PersistentVolumeClaim
from huaweicloudsdkcce.v3.model.persistent_volume_claim_metadata import PersistentVolumeClaimMetadata
from huaweicloudsdkcce.v3.model.persistent_volume_claim_spec import PersistentVolumeClaimSpec
from huaweicloudsdkcce.v3.model.persistent_volume_claim_status import PersistentVolumeClaimStatus
from huaweicloudsdkcce.v3.model.resource_requirements import ResourceRequirements
from huaweicloudsdkcce.v3.model.resource_tag import ResourceTag
from huaweicloudsdkcce.v3.model.show_addon_instance_request import ShowAddonInstanceRequest
from huaweicloudsdkcce.v3.model.show_addon_instance_response import ShowAddonInstanceResponse
from huaweicloudsdkcce.v3.model.show_cluster_metadata import ShowClusterMetadata
from huaweicloudsdkcce.v3.model.show_cluster_request import ShowClusterRequest
from huaweicloudsdkcce.v3.model.show_cluster_response import ShowClusterResponse
from huaweicloudsdkcce.v3.model.show_job_request import ShowJobRequest
from huaweicloudsdkcce.v3.model.show_job_response import ShowJobResponse
from huaweicloudsdkcce.v3.model.show_node_pool_request import ShowNodePoolRequest
from huaweicloudsdkcce.v3.model.show_node_pool_response import ShowNodePoolResponse
from huaweicloudsdkcce.v3.model.show_node_request import ShowNodeRequest
from huaweicloudsdkcce.v3.model.show_node_response import ShowNodeResponse
from huaweicloudsdkcce.v3.model.support_versions import SupportVersions
from huaweicloudsdkcce.v3.model.taint import Taint
from huaweicloudsdkcce.v3.model.templatespec import Templatespec
from huaweicloudsdkcce.v3.model.update_addon_instance_request import UpdateAddonInstanceRequest
from huaweicloudsdkcce.v3.model.update_addon_instance_response import UpdateAddonInstanceResponse
from huaweicloudsdkcce.v3.model.update_cluster_request import UpdateClusterRequest
from huaweicloudsdkcce.v3.model.update_cluster_response import UpdateClusterResponse
from huaweicloudsdkcce.v3.model.update_node_pool_request import UpdateNodePoolRequest
from huaweicloudsdkcce.v3.model.update_node_pool_response import UpdateNodePoolResponse
from huaweicloudsdkcce.v3.model.update_node_request import UpdateNodeRequest
from huaweicloudsdkcce.v3.model.update_node_response import UpdateNodeResponse
from huaweicloudsdkcce.v3.model.user import User
from huaweicloudsdkcce.v3.model.user_password import UserPassword
from huaweicloudsdkcce.v3.model.user_tag import UserTag
from huaweicloudsdkcce.v3.model.users import Users
from huaweicloudsdkcce.v3.model.v3_cluster import V3Cluster
from huaweicloudsdkcce.v3.model.v3_cluster_spec import V3ClusterSpec
from huaweicloudsdkcce.v3.model.v3_data_volume import V3DataVolume
from huaweicloudsdkcce.v3.model.v3_node import V3Node
from huaweicloudsdkcce.v3.model.v3_node_bandwidth import V3NodeBandwidth
from huaweicloudsdkcce.v3.model.v3_node_create_request import V3NodeCreateRequest
from huaweicloudsdkcce.v3.model.v3_node_eip_spec import V3NodeEIPSpec
from huaweicloudsdkcce.v3.model.v3_node_public_ip import V3NodePublicIP
from huaweicloudsdkcce.v3.model.v3_node_spec import V3NodeSpec
from huaweicloudsdkcce.v3.model.v3_node_status import V3NodeStatus
from huaweicloudsdkcce.v3.model.v3_root_volume import V3RootVolume
from huaweicloudsdkcce.v3.model.versions import Versions
